( cd usr/lib ; rm -rf libsfftw.so )
( cd usr/lib ; ln -sf libsfftw.so.2.0.7 libsfftw.so )
( cd usr/lib ; rm -rf librfftw_threads.so )
( cd usr/lib ; ln -sf librfftw_threads.so.2.0.7 librfftw_threads.so )
( cd usr/lib ; rm -rf librfftw.so )
( cd usr/lib ; ln -sf librfftw.so.2.0.7 librfftw.so )
( cd usr/lib ; rm -rf libfftw_threads.so.2 )
( cd usr/lib ; ln -sf libfftw_threads.so.2.0.7 libfftw_threads.so.2 )
( cd usr/lib ; rm -rf libsrfftw.so.2 )
( cd usr/lib ; ln -sf libsrfftw.so.2.0.7 libsrfftw.so.2 )
( cd usr/lib ; rm -rf librfftw.so.2 )
( cd usr/lib ; ln -sf librfftw.so.2.0.7 librfftw.so.2 )
( cd usr/lib ; rm -rf libdfftw_threads.so )
( cd usr/lib ; ln -sf libdfftw_threads.so.2.0.7 libdfftw_threads.so )
( cd usr/lib ; rm -rf libsrfftw.so )
( cd usr/lib ; ln -sf libsrfftw.so.2.0.7 libsrfftw.so )
( cd usr/lib ; rm -rf libsfftw.so.2 )
( cd usr/lib ; ln -sf libsfftw.so.2.0.7 libsfftw.so.2 )
( cd usr/lib ; rm -rf libdrfftw_threads.so.2 )
( cd usr/lib ; ln -sf libdrfftw_threads.so.2.0.7 libdrfftw_threads.so.2 )
( cd usr/lib ; rm -rf libsfftw_threads.so.2 )
( cd usr/lib ; ln -sf libsfftw_threads.so.2.0.7 libsfftw_threads.so.2 )
( cd usr/lib ; rm -rf libsfftw_threads.so )
( cd usr/lib ; ln -sf libsfftw_threads.so.2.0.7 libsfftw_threads.so )
( cd usr/lib ; rm -rf libdfftw.so.2 )
( cd usr/lib ; ln -sf libdfftw.so.2.0.7 libdfftw.so.2 )
( cd usr/lib ; rm -rf libdfftw_threads.so.2 )
( cd usr/lib ; ln -sf libdfftw_threads.so.2.0.7 libdfftw_threads.so.2 )
( cd usr/lib ; rm -rf libdfftw.so )
( cd usr/lib ; ln -sf libdfftw.so.2.0.7 libdfftw.so )
( cd usr/lib ; rm -rf libfftw_threads.so )
( cd usr/lib ; ln -sf libfftw_threads.so.2.0.7 libfftw_threads.so )
( cd usr/lib ; rm -rf libdrfftw.so )
( cd usr/lib ; ln -sf libdrfftw.so.2.0.7 libdrfftw.so )
( cd usr/lib ; rm -rf libfftw.so.2 )
( cd usr/lib ; ln -sf libfftw.so.2.0.7 libfftw.so.2 )
( cd usr/lib ; rm -rf libfftw.so )
( cd usr/lib ; ln -sf libfftw.so.2.0.7 libfftw.so )
( cd usr/lib ; rm -rf libdrfftw_threads.so )
( cd usr/lib ; ln -sf libdrfftw_threads.so.2.0.7 libdrfftw_threads.so )
( cd usr/lib ; rm -rf libdrfftw.so.2 )
( cd usr/lib ; ln -sf libdrfftw.so.2.0.7 libdrfftw.so.2 )
( cd usr/lib ; rm -rf librfftw_threads.so.2 )
( cd usr/lib ; ln -sf librfftw_threads.so.2.0.7 librfftw_threads.so.2 )
( cd usr/lib ; rm -rf libsrfftw_threads.so.2 )
( cd usr/lib ; ln -sf libsrfftw_threads.so.2.0.7 libsrfftw_threads.so.2 )
( cd usr/lib ; rm -rf libsrfftw_threads.so )
( cd usr/lib ; ln -sf libsrfftw_threads.so.2.0.7 libsrfftw_threads.so )
